/* This file was generated by syncqt. */
#ifndef QT_QTLABSSHAREDIMAGE_VERSION_H
#define QT_QTLABSSHAREDIMAGE_VERSION_H

#define QTLABSSHAREDIMAGE_VERSION_STR "6.11.0"

#define QTLABSSHAREDIMAGE_VERSION 0x0601100

#endif // QT_QTLABSSHAREDIMAGE_VERSION_H
